#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

install_requires = \
['six>=1.9', 'mutagen>=1.45']

extras_require = \
{'test': ['tox']}

setup(name='mediafile',
      version='0.9.0',
      description="Handles low-level interfacing for files' tags. Wraps Mutagen to",
      author='Adrian Sampson',
      author_email='adrian@radbox.org',
      url='https://github.com/beetbox/mediafile',
      py_modules=['mediafile'],
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
